"""
Test operations

This file is just there to help demonstrate the initial setup.
You will probably delete it early in the project.
"""
from continuous_timeseries.operations import add_two


def test_add_two():
    assert add_two(3.3, 4.4) == 7.7



"""
Operations

This module is just there to help with doc building etc. on project creation.
You will probably delete it early in the project.
"""
from __future__ import annotations


def add_two(a: float, b: float) -> float:
    """
    Add two numbers

    Parameters
    ----------
    a
        First number

    b
        Second number

    Returns
    -------
    :
        Sum of the numbers

    Examples
    --------
    >>> add_two(1, 3)
    4
    >>> add_two(1, -3)
    -2
    """
    return a + b
